==> plplot-5.12.0.tar.gz: plplot-5.12.0/doc/doxygen/html/search/variables_18.js <==
var searchData=
[
  ['x',['x',['../structpoint.html#a9c6b34deaf4900ad4193c17935fd384a',1,'point::x()'],['../structcdPointStruct.html#a59756f6e1413af2b86970c3d294734f2',1,'cdPointStruct::x()'],['../structcircle.html#a3ecd01f4a611905b29614e61d8c6f068',1,'circle::x()'],['../structnnai.html#a0b6ac59eb24c1da56cf0ef313f6d185a',1,'nnai::x()'],['../structpoint.html#ab641445b415b4b74bcb9d2bc1165da06',1,'point::x()'],['../structPLStrip.html#a4660959698a80fa623df1c94db1f26ec',1,'PLStrip::x()'],['../structplplot_1_1__N4.html#a83c5abebc9d43e55f9bbc55c3fd4aec8',1,'plplot::_N4::x()'],['../structPLDisplay.html#a62213c78625145fa92cc560c5aacda62',1,'PLDisplay::x()'],['../structEscText.html#a68ab177efc37ee7d7a491c4c16ecc0c3',1,'EscText::x()'],['../structcont__line.html#a19d534dd5e2a416be86b7fbdddb9d142',1,'cont_line::x()'],['../structarc__struct.html#a13e4b9634f44fdb017d224f3a6fdc7af',1,'arc_struct::x()']]],
  ['x_5fpolygon',['x_polygon',['../structPLStream.html#a642f1db20ff569a772ee88762d9671c6',1,'PLStream']]],
  ['xdigits',['xdigits',['../structPLStream.html#ae74914a0b58f1d8315ed2c72fae2f6f5',1,'PLStream']]],
  ['xdigmax',['xdigmax',['../structPLStream.html#abe70e4b3e2130f7a25e67c9b49c70ad8',1,'PLStream']]],
  ['xdpi',['xdpi',['../structPLStream.html#a2d24d9a093f447144c8f3ea9cac2d349',1,'PLStream']]],
  ['xform',['xform',['../structEscText.html#ae0f4c1c790597d359c13f35ea409670c',1,'EscText']]],
  ['xg',['xg',['../classcxx__pltr2.html#a07b70acf43c8223b95d27e3792cfc0cd',1,'cxx_pltr2::xg()'],['../structplplot_1_1PLcGrid.html#ab79e29e9d6066868e145323ab8b2e1c7',1,'plplot::PLcGrid::xg()'],['../structplplot_1_1PLcGrid2.html#a7c45933d67e0b15ee227f39cebcb57d5',1,'plplot::PLcGrid2::xg()'],['../structplplot_1_1__N7.html#af0c3ecbae3e12785c6c7334840faf618',1,'plplot::_N7::xg()'],['../structplplot_1_1__N8.html#a1404ed8d26b06cbd800674449623c973',1,'plplot::_N8::xg()'],['../structplplot__types_1_1plcgrid.html#aa52fb86071bfce2288e184ba5dd836da',1,'plplot_types::plcgrid::xg()'],['../structPLcGrid.html#a1c5faea0b8b710068908a6550c638e97',1,'PLcGrid::xg()'],['../structPLcGrid2.html#a5dc6e0ee10871fbbe5594c7a5ee41cff',1,'PLcGrid2::xg()']]],
  ['xgradient',['xgradient',['../structPLStream.html#a962465c1e71ed607052e2a1e36d0b4b5',1,'PLStream']]],
  ['xhair_5fcursor',['xhair_cursor',['../structPlFrame.html#a318fb1957be2cf5100382b63b70a430c',1,'PlFrame::xhair_cursor()'],['../structPlPlotter.html#a8038e60689df995da5850b9e55b2aaf0',1,'PlPlotter::xhair_cursor()'],['../structTkwDisplay.html#a6139c89bf30f02dfff34f03c61689e83',1,'TkwDisplay::xhair_cursor()'],['../structXwDisplay.html#a6552c5aaf33176576a63e04d1aaaf1c2',1,'XwDisplay::xhair_cursor()']]],
  ['xhair_5fx',['xhair_x',['../structPlFrame.html#a46f5281c2ffaeeebb3e6b647146504aa',1,'PlFrame::xhair_x()'],['../structPlPlotter.html#a6a56bd300e78debc52c3dcdd54b58dbc',1,'PlPlotter::xhair_x()'],['../structTkwDev.html#a54a54be9d73bb9b2a2a2f70040098417',1,'TkwDev::xhair_x()'],['../structXwDev.html#a8c9320476b050715844e47622e810acc',1,'XwDev::xhair_x()']]],
  ['xhair_5fy',['xhair_y',['../structPlFrame.html#a3438180cbe692046829c53572feb5532',1,'PlFrame::xhair_y()'],['../structPlPlotter.html#ae1222cc0592bae1535ee21ca0a221a24',1,'PlPlotter::xhair_y()'],['../structTkwDev.html#a9c49c6903ac152b71e5655c2485a7697',1,'TkwDev::xhair_y()'],['../structXwDev.html#a22f8badb9ccd42d0c87a0ba67678041a',1,'XwDev::xhair_y()']]],
  ['xhairs',['xhairs',['../structPlFrame.html#aa6cb6a7735777e0cda710ec4927b0313',1,'PlFrame::xhairs()'],['../structPlPlotter.html#a0fc0b3d8558ac58c215e3bfce3dad258',1,'PlPlotter::xhairs()']]],
  ['xjump',['xjump',['../structPLStrip.html#a13972def69a7a1548ce8bf2acb0f0284',1,'PLStrip']]],
  ['xl',['xl',['../structPlFrame.html#af6f16b79c15278059fd0bd7d370e07e2',1,'PlFrame::xl()'],['../structPlPlotter.html#a66bd1a5e7725e351d41cfaf03945e29d',1,'PlPlotter::xl()']]],
  ['xlen',['xlen',['../structPLStrip.html#aa1cd593de173fee73497255163ad2af8',1,'PLStrip::xlen()'],['../structTkwDev.html#a0b2b3fe6c37270c0b529aec3bfd6eccd',1,'TkwDev::xlen()'],['../structPLmDev.html#a2b24768855ccef34822aee956bbd0ddc',1,'PLmDev::xlen()'],['../structPLDev.html#accce2060bae1cc76ad8a2db7eea9d16f',1,'PLDev::xlen()'],['../structXwDev.html#a3d731b5b4b18c8b251f8da8b26c37ce7',1,'XwDev::xlen()'],['../structPSDev.html#abc7cd2683d76b21bf36db57c9c88b065',1,'PSDev::xlen()'],['../plplotluacLUA__wrap_8c.html#ac91c25f032882cfbd3e877adb9dd788d',1,'Xlen():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ac91c25f032882cfbd3e877adb9dd788d',1,'Xlen():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#ac91c25f032882cfbd3e877adb9dd788d',1,'Xlen():&#160;plplotcmodulePYTHON_wrap.c']]],
  ['xlen_5fdev',['xlen_dev',['../structPLDev.html#a3709cfc99512abce169bd3df8348cb96',1,'PLDev::xlen_dev()'],['../structPSDev.html#aeb1891067ff2bbdd9160dacfe54bb3bb',1,'PSDev::xlen_dev()']]],
  ['xlength',['xlength',['../structPLStream.html#ac3040626ec1dc9a402d30722ecb33bf1',1,'PLStream']]],
  ['xlight',['xlight',['../plot3d_8c.html#aad6a6898e409195bd546ea1567958dde',1,'plot3d.c']]],
  ['xline',['xline',['../plline_8c.html#a9c6e8f4fa496169d0e88ee996dfdfa3e',1,'plline.c']]],
  ['xlog',['xlog',['../plbox_8c.html#a0a95b90ff806fdcd4b4f467304afd362',1,'plbox.c']]],
  ['xlpos',['xlpos',['../structPLStrip.html#a2ca2b540e73fbdfe58aa8442a7c46ab0',1,'PLStrip']]],
  ['xmax',['xmax',['../structcsa.html#add6062ece5ecd76ff294be8316ecec26',1,'csa::xmax()'],['../structdelaunay.html#a99856a7474ade7ae013826c51286d36f',1,'delaunay::xmax()'],['../structPLStrip.html#ad85b8ac965e271f8a862996d1c20da16',1,'PLStrip::xmax()'],['../structPLRDev.html#a5a478a9f0ef2f92635dc6539b430d391',1,'PLRDev::xmax()'],['../structPLmDev.html#aff750472fb79ce20c329eda3e7e9d7b3',1,'PLmDev::xmax()'],['../structPLDev.html#a8ff24377a9e0457fa6e3c060cc5ee145',1,'PLDev::xmax()'],['../structPSDev.html#adfb3038a27e60ad3d7eabfb4b9c84d2a',1,'PSDev::xmax()']]],
  ['xmax_5fdev',['xmax_dev',['../structPLDev.html#a8d33f07b5696b26dbe2ed8648cbeec93',1,'PLDev::xmax_dev()'],['../structPSDev.html#a50af04cad55e158e195fe0d96029bdba',1,'PSDev::xmax_dev()']]],
  ['xmin',['xmin',['../structcsa.html#a005399c1a1a23bcf46c2f4ed3acc70bd',1,'csa::xmin()'],['../structdelaunay.html#adfaa7a8743255547db60acdf55a90b96',1,'delaunay::xmin()'],['../structPLStrip.html#a952a2f41f34f9295ad7c29c9fc2ea950',1,'PLStrip::xmin()'],['../structPLRDev.html#adc1db0719f2952bc0152fc50c2e50302',1,'PLRDev::xmin()'],['../structPLmDev.html#aebd0f535a8753477736ffcf8302e0e2f',1,'PLmDev::xmin()'],['../structIMG__DT.html#a2a967ce77593f3362dda17c0c7385ff9',1,'IMG_DT::xmin()'],['../structPLDev.html#aff0304a2dcc0db26abbec401b5eb25c6',1,'PLDev::xmin()'],['../structPSDev.html#a726f94977509580d43eec85fb5d30f59',1,'PSDev::xmin()']]],
  ['xmin_5fdev',['xmin_dev',['../structPLDev.html#a4be70c9c75177f43ac2500903dfde560',1,'PLDev::xmin_dev()'],['../structPSDev.html#add0168298b323516c82e0bc4bc13983b',1,'PSDev::xmin_dev()']]],
  ['xoffset',['xoffset',['../structPLStream.html#a59aa7205e849ddd9b67c95420bf3bffe',1,'PLStream::xoffset()'],['../classQtPLDriver.html#aa5459c458d794c0536fdde23d059406d',1,'QtPLDriver::xOffset()']]],
  ['xold',['xold',['../structPLRDev.html#a1b93a8aba2e97f23d7b031a5a224baed',1,'PLRDev::xold()'],['../structTkDev.html#a73901cd7a8e8278fc8dd96f2a1fcbeb6',1,'TkDev::xold()'],['../structPLmDev.html#aef98ee70a88c95f339a4f32b9bd38468',1,'PLmDev::xold()'],['../structPLDev.html#ab71f661ba3049e35e4ee427050d25b10',1,'PLDev::xold()'],['../structPSDev.html#a9753ff4a7c6ea93ba7ea8fca2cf67462',1,'PSDev::xold()']]],
  ['xorgc',['xorGC',['../structPlFrame.html#a3c44e36073bc6376f90f5fcbe4b87fab',1,'PlFrame::xorGC()'],['../structPlPlotter.html#a343431d349fd3ae0f118fc3773144c17',1,'PlPlotter::xorGC()']]],
  ['xpmm',['xpmm',['../structPLStream.html#af2865bcc032aafba071341ba183d6c39',1,'PLStream']]],
  ['xr',['xr',['../structPlFrame.html#ae0703e81c08538367597a73dd4c5ace5',1,'PlFrame::xr()'],['../structPlPlotter.html#ab59fc3646770e4ea56d07cc6571738d5',1,'PlPlotter::xr()']]],
  ['xscale',['xscale',['../structTkwDev.html#a1eb3486bbaf2b1e6b072b1d45f425d8a',1,'TkwDev::xscale()'],['../structXwDev.html#aa41887e1899134845023b2868284b4e1',1,'XwDev::xscale()']]],
  ['xscale_5fdev',['xscale_dev',['../structPLDev.html#a2dcdd758ca8617de48f6385680625a2b',1,'PLDev::xscale_dev()'],['../structPSDev.html#a3ee25ec6befa7fb3e6978e597fb0bce4',1,'PSDev::xscale_dev()']]],
  ['xscale_5finit',['xscale_init',['../structTkwDev.html#a03cdf193ac3d14fa84f0d6973c9be74a',1,'TkwDev::xscale_init()'],['../structXwDev.html#aa9e5fd88266088b9d1713bf5d7cb852e',1,'XwDev::xscale_init()']]],
  ['xscl',['xscl',['../plcore_8h.html#a03d457bab6d6453e8908e9f15ce934cb',1,'plcore.h']]],
  ['xscrollcmd',['xScrollCmd',['../structPlFrame.html#ad0999e4635a9f983fab3d11f00192d26',1,'PlFrame::xScrollCmd()'],['../structPlPlotter.html#ae76e603da0193d72ca4637cac2f560f7',1,'PlPlotter::xScrollCmd()']]],
  ['xspec',['xspec',['../structPLStrip.html#adc115b34ba8fc329c7e5f6c59e7e6851',1,'PLStrip']]],
  ['xspline',['xspline',['../deltaT_8h.html#af59f4aee7c8f356159002683266ce76b',1,'deltaT.h']]],
  ['xstatic',['xstatic',['../plr_8c.html#a31b2255163007011464d306da5c63c38',1,'plr.c']]],
  ['xwd',['xwd',['../structXwDev.html#a4c2092d756a40efcfef5bcfc13c74667',1,'XwDev']]],
  ['xxhi',['xxhi',['../plot3d_8c.html#af6dfaf4bf98f307129151a4fd29a1764',1,'plot3d.c']]],
  ['xxlo',['xxlo',['../plot3d_8c.html#acf24948e61b6717f784170163d3cc403',1,'plot3d.c']]],
  ['xygrid',['xygrid',['../plsym_8c.html#a5865049794d5ed1a5b1941944ade217b',1,'plsym.c']]]
];

==> plplot-5.13.0.tar.gz: plplot-5.13.0/doc/doxygen/html/search/variables_18.js <==
var searchData=
[
  ['x',['x',['../structpoint.html#a9c6b34deaf4900ad4193c17935fd384a',1,'point::x()'],['../structcdPointStruct.html#a59756f6e1413af2b86970c3d294734f2',1,'cdPointStruct::x()'],['../structcircle.html#a3ecd01f4a611905b29614e61d8c6f068',1,'circle::x()'],['../structnnai.html#a0b6ac59eb24c1da56cf0ef313f6d185a',1,'nnai::x()'],['../structpoint.html#ab641445b415b4b74bcb9d2bc1165da06',1,'point::x()'],['../structPLStrip.html#a4660959698a80fa623df1c94db1f26ec',1,'PLStrip::x()'],['../structplplot_1_1__N4.html#a83c5abebc9d43e55f9bbc55c3fd4aec8',1,'plplot::_N4::x()'],['../structPLDisplay.html#a62213c78625145fa92cc560c5aacda62',1,'PLDisplay::x()'],['../structEscText.html#a68ab177efc37ee7d7a491c4c16ecc0c3',1,'EscText::x()'],['../structcont__line.html#a19d534dd5e2a416be86b7fbdddb9d142',1,'cont_line::x()'],['../structarc__struct.html#a13e4b9634f44fdb017d224f3a6fdc7af',1,'arc_struct::x()']]],
  ['x_5fpolygon',['x_polygon',['../structPLStream.html#a642f1db20ff569a772ee88762d9671c6',1,'PLStream']]],
  ['xdigits',['xdigits',['../structPLStream.html#ae74914a0b58f1d8315ed2c72fae2f6f5',1,'PLStream']]],
  ['xdigmax',['xdigmax',['../structPLStream.html#abe70e4b3e2130f7a25e67c9b49c70ad8',1,'PLStream']]],
  ['xdpi',['xdpi',['../structPLStream.html#a2d24d9a093f447144c8f3ea9cac2d349',1,'PLStream']]],
  ['xform',['xform',['../structEscText.html#ae0f4c1c790597d359c13f35ea409670c',1,'EscText']]],
  ['xg',['xg',['../classcxx__pltr2.html#a07b70acf43c8223b95d27e3792cfc0cd',1,'cxx_pltr2::xg()'],['../structplplot_1_1PLcGrid.html#ab79e29e9d6066868e145323ab8b2e1c7',1,'plplot::PLcGrid::xg()'],['../structplplot_1_1PLcGrid2.html#a7c45933d67e0b15ee227f39cebcb57d5',1,'plplot::PLcGrid2::xg()'],['../structplplot_1_1__N7.html#af0c3ecbae3e12785c6c7334840faf618',1,'plplot::_N7::xg()'],['../structplplot_1_1__N8.html#a1404ed8d26b06cbd800674449623c973',1,'plplot::_N8::xg()'],['../structplplot__types_1_1plcgrid.html#aa52fb86071bfce2288e184ba5dd836da',1,'plplot_types::plcgrid::xg()'],['../structPLcGrid.html#a1c5faea0b8b710068908a6550c638e97',1,'PLcGrid::xg()'],['../structPLcGrid2.html#a5dc6e0ee10871fbbe5594c7a5ee41cff',1,'PLcGrid2::xg()']]],
  ['xgradient',['xgradient',['../structPLStream.html#a962465c1e71ed607052e2a1e36d0b4b5',1,'PLStream']]],
  ['xhair_5fcursor',['xhair_cursor',['../structPlFrame.html#a318fb1957be2cf5100382b63b70a430c',1,'PlFrame::xhair_cursor()'],['../structPlPlotter.html#a8038e60689df995da5850b9e55b2aaf0',1,'PlPlotter::xhair_cursor()'],['../structTkwDisplay.html#a6139c89bf30f02dfff34f03c61689e83',1,'TkwDisplay::xhair_cursor()'],['../structXwDisplay.html#a6552c5aaf33176576a63e04d1aaaf1c2',1,'XwDisplay::xhair_cursor()']]],
  ['xhair_5fx',['xhair_x',['../structPlFrame.html#a46f5281c2ffaeeebb3e6b647146504aa',1,'PlFrame::xhair_x()'],['../structPlPlotter.html#a6a56bd300e78debc52c3dcdd54b58dbc',1,'PlPlotter::xhair_x()'],['../structTkwDev.html#a54a54be9d73bb9b2a2a2f70040098417',1,'TkwDev::xhair_x()'],['../structXwDev.html#a8c9320476b050715844e47622e810acc',1,'XwDev::xhair_x()']]],
  ['xhair_5fy',['xhair_y',['../structPlFrame.html#a3438180cbe692046829c53572feb5532',1,'PlFrame::xhair_y()'],['../structPlPlotter.html#ae1222cc0592bae1535ee21ca0a221a24',1,'PlPlotter::xhair_y()'],['../structTkwDev.html#a9c49c6903ac152b71e5655c2485a7697',1,'TkwDev::xhair_y()'],['../structXwDev.html#a22f8badb9ccd42d0c87a0ba67678041a',1,'XwDev::xhair_y()']]],
  ['xhairs',['xhairs',['../structPlFrame.html#aa6cb6a7735777e0cda710ec4927b0313',1,'PlFrame::xhairs()'],['../structPlPlotter.html#a0fc0b3d8558ac58c215e3bfce3dad258',1,'PlPlotter::xhairs()']]],
  ['xjump',['xjump',['../structPLStrip.html#a13972def69a7a1548ce8bf2acb0f0284',1,'PLStrip']]],
  ['xl',['xl',['../structPlFrame.html#af6f16b79c15278059fd0bd7d370e07e2',1,'PlFrame::xl()'],['../structPlPlotter.html#a66bd1a5e7725e351d41cfaf03945e29d',1,'PlPlotter::xl()']]],
  ['xlen',['xlen',['../structPLStrip.html#aa1cd593de173fee73497255163ad2af8',1,'PLStrip::xlen()'],['../structTkwDev.html#a0b2b3fe6c37270c0b529aec3bfd6eccd',1,'TkwDev::xlen()'],['../structPLmDev.html#a2b24768855ccef34822aee956bbd0ddc',1,'PLmDev::xlen()'],['../structPLDev.html#accce2060bae1cc76ad8a2db7eea9d16f',1,'PLDev::xlen()'],['../structXwDev.html#a3d731b5b4b18c8b251f8da8b26c37ce7',1,'XwDev::xlen()'],['../structPSDev.html#abc7cd2683d76b21bf36db57c9c88b065',1,'PSDev::xlen()'],['../plplotluacLUA__wrap_8c.html#ac91c25f032882cfbd3e877adb9dd788d',1,'Xlen():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ac91c25f032882cfbd3e877adb9dd788d',1,'Xlen():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#ac91c25f032882cfbd3e877adb9dd788d',1,'Xlen():&#160;plplotcPYTHON_wrap.c']]],
  ['xlen_5fdev',['xlen_dev',['../structPLDev.html#a3709cfc99512abce169bd3df8348cb96',1,'PLDev::xlen_dev()'],['../structPSDev.html#aeb1891067ff2bbdd9160dacfe54bb3bb',1,'PSDev::xlen_dev()']]],
  ['xlength',['xlength',['../structPLStream.html#ac3040626ec1dc9a402d30722ecb33bf1',1,'PLStream']]],
  ['xlight',['xlight',['../plot3d_8c.html#aad6a6898e409195bd546ea1567958dde',1,'plot3d.c']]],
  ['xline',['xline',['../plline_8c.html#a9c6e8f4fa496169d0e88ee996dfdfa3e',1,'plline.c']]],
  ['xlog',['xlog',['../plbox_8c.html#a0a95b90ff806fdcd4b4f467304afd362',1,'plbox.c']]],
  ['xlpos',['xlpos',['../structPLStrip.html#a2ca2b540e73fbdfe58aa8442a7c46ab0',1,'PLStrip']]],
  ['xmax',['xmax',['../structcsa.html#add6062ece5ecd76ff294be8316ecec26',1,'csa::xmax()'],['../structdelaunay.html#a99856a7474ade7ae013826c51286d36f',1,'delaunay::xmax()'],['../structPLStrip.html#ad85b8ac965e271f8a862996d1c20da16',1,'PLStrip::xmax()'],['../structPLRDev.html#a5a478a9f0ef2f92635dc6539b430d391',1,'PLRDev::xmax()'],['../structPLmDev.html#aff750472fb79ce20c329eda3e7e9d7b3',1,'PLmDev::xmax()'],['../structPLDev.html#a8ff24377a9e0457fa6e3c060cc5ee145',1,'PLDev::xmax()'],['../structPSDev.html#adfb3038a27e60ad3d7eabfb4b9c84d2a',1,'PSDev::xmax()']]],
  ['xmax_5fdev',['xmax_dev',['../structPLDev.html#a8d33f07b5696b26dbe2ed8648cbeec93',1,'PLDev::xmax_dev()'],['../structPSDev.html#a50af04cad55e158e195fe0d96029bdba',1,'PSDev::xmax_dev()']]],
  ['xmin',['xmin',['../structcsa.html#a005399c1a1a23bcf46c2f4ed3acc70bd',1,'csa::xmin()'],['../structdelaunay.html#adfaa7a8743255547db60acdf55a90b96',1,'delaunay::xmin()'],['../structPLStrip.html#a952a2f41f34f9295ad7c29c9fc2ea950',1,'PLStrip::xmin()'],['../structPLRDev.html#adc1db0719f2952bc0152fc50c2e50302',1,'PLRDev::xmin()'],['../structPLmDev.html#aebd0f535a8753477736ffcf8302e0e2f',1,'PLmDev::xmin()'],['../structIMG__DT.html#a2a967ce77593f3362dda17c0c7385ff9',1,'IMG_DT::xmin()'],['../structPLDev.html#aff0304a2dcc0db26abbec401b5eb25c6',1,'PLDev::xmin()'],['../structPSDev.html#a726f94977509580d43eec85fb5d30f59',1,'PSDev::xmin()']]],
  ['xmin_5fdev',['xmin_dev',['../structPLDev.html#a4be70c9c75177f43ac2500903dfde560',1,'PLDev::xmin_dev()'],['../structPSDev.html#add0168298b323516c82e0bc4bc13983b',1,'PSDev::xmin_dev()']]],
  ['xoffset',['xOffset',['../classQtPLDriver.html#aa5459c458d794c0536fdde23d059406d',1,'QtPLDriver::xOffset()'],['../structPLStream.html#a59aa7205e849ddd9b67c95420bf3bffe',1,'PLStream::xoffset()']]],
  ['xold',['xold',['../structPLRDev.html#a1b93a8aba2e97f23d7b031a5a224baed',1,'PLRDev::xold()'],['../structTkDev.html#a73901cd7a8e8278fc8dd96f2a1fcbeb6',1,'TkDev::xold()'],['../structPLmDev.html#aef98ee70a88c95f339a4f32b9bd38468',1,'PLmDev::xold()'],['../structPLDev.html#ab71f661ba3049e35e4ee427050d25b10',1,'PLDev::xold()'],['../structPSDev.html#a9753ff4a7c6ea93ba7ea8fca2cf67462',1,'PSDev::xold()']]],
  ['xorgc',['xorGC',['../structPlFrame.html#a3c44e36073bc6376f90f5fcbe4b87fab',1,'PlFrame::xorGC()'],['../structPlPlotter.html#a343431d349fd3ae0f118fc3773144c17',1,'PlPlotter::xorGC()']]],
  ['xpmm',['xpmm',['../structPLStream.html#af2865bcc032aafba071341ba183d6c39',1,'PLStream']]],
  ['xr',['xr',['../structPlFrame.html#ae0703e81c08538367597a73dd4c5ace5',1,'PlFrame::xr()'],['../structPlPlotter.html#ab59fc3646770e4ea56d07cc6571738d5',1,'PlPlotter::xr()']]],
  ['xscale',['xscale',['../structTkwDev.html#a1eb3486bbaf2b1e6b072b1d45f425d8a',1,'TkwDev::xscale()'],['../structXwDev.html#aa41887e1899134845023b2868284b4e1',1,'XwDev::xscale()']]],
  ['xscale_5fdev',['xscale_dev',['../structPLDev.html#a2dcdd758ca8617de48f6385680625a2b',1,'PLDev::xscale_dev()'],['../structPSDev.html#a3ee25ec6befa7fb3e6978e597fb0bce4',1,'PSDev::xscale_dev()']]],
  ['xscale_5finit',['xscale_init',['../structTkwDev.html#a03cdf193ac3d14fa84f0d6973c9be74a',1,'TkwDev::xscale_init()'],['../structXwDev.html#aa9e5fd88266088b9d1713bf5d7cb852e',1,'XwDev::xscale_init()']]],
  ['xscl',['xscl',['../plcore_8h.html#a03d457bab6d6453e8908e9f15ce934cb',1,'plcore.h']]],
  ['xscrollcmd',['xScrollCmd',['../structPlFrame.html#ad0999e4635a9f983fab3d11f00192d26',1,'PlFrame::xScrollCmd()'],['../structPlPlotter.html#ae76e603da0193d72ca4637cac2f560f7',1,'PlPlotter::xScrollCmd()']]],
  ['xspec',['xspec',['../structPLStrip.html#adc115b34ba8fc329c7e5f6c59e7e6851',1,'PLStrip']]],
  ['xspline',['xspline',['../deltaT_8h.html#af59f4aee7c8f356159002683266ce76b',1,'deltaT.h']]],
  ['xstatic',['xstatic',['../plr_8c.html#a31b2255163007011464d306da5c63c38',1,'plr.c']]],
  ['xwd',['xwd',['../structXwDev.html#a4c2092d756a40efcfef5bcfc13c74667',1,'XwDev']]],
  ['xxhi',['xxhi',['../plot3d_8c.html#af6dfaf4bf98f307129151a4fd29a1764',1,'plot3d.c']]],
  ['xxlo',['xxlo',['../plot3d_8c.html#acf24948e61b6717f784170163d3cc403',1,'plot3d.c']]],
  ['xygrid',['xygrid',['../plsym_8c.html#a5865049794d5ed1a5b1941944ade217b',1,'plsym.c']]]
];
